<?php

namespace Service\OAuth;

use Zeedhi\Framework\Security\OAuth\Service;
use \Zeedhi\Framework\Security\OAuth\ServiceProvider;
use Doctrine\ORM\EntityManager;

class ServiceProviderImpl implements ServiceProvider {

    const SERVICES_PATH =  "/../../../service/json/customers.json";

    /** @var string */
    private $servicePath;

    function __construct(
        EntityManager $entityManager,
        $servicePath = self::SERVICES_PATH
    ) {
        $this->servicePath = $servicePath;
        $this->connection = $entityManager->getConnection();
    }


    /**
     * This method must find a service using the client ID and client secret properties
     *
     * @param  string $clientId A client ID property
     * @param  string $clientSecret A client secret property
     *
     * @return Service  An instance of the service
     */
    public function findByClientAndSecretId($clientId, $clientSecret) {
        $service = $this->getOrgAuthInfo($clientId);

        if($service && $service['NRORG'] == $clientId && $service['CLIENT_SECRET'] == $clientSecret) {
            $serviceImpl = new ServiceImpl(
                $service['NMORGANIZACAO'],
                $service['NRORG'],
                $service['CLIENT_SECRET'],
                $service['NRORG']
            );

            return $serviceImpl;
        }

        return null;
    }

    public function getOrgAuthInfo(
        int $nrOrg
    ) {
        $params = [
            'P_NRORG' => $nrOrg
        ];

        $sql = <<< SQL
            SELECT NMORGANIZACAO,
                   NRORG,
                   CLIENT_SECRET
            FROM ORGANIZACAO
            WHERE NRORG = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $orgAuthInfo = $std->fetch();

        return $orgAuthInfo;
    }
}